@@ -1,37 +1,18 @@
 import base64
 import cv2
 import numpy as np
-
 import pyrfuniverse.attributes as attr
 import pyrfuniverse.utils.active_depth_generate as active_depth
-import pyrfuniverse.utils.rfuniverse_utility as utility
 from pyrfuniverse.side_channel.side_channel import (
     IncomingMessage,
     OutgoingMessage,
 )
 
-main_intrinsic_matrix = np.array([[1380, 0, 800], [0, 1380, 450], [0, 0, 1]])
-ir_intrinsic_matrix = np.array([[920, 0, 640], [0, 920, 360], [0, 0, 1]])
-
-
-def GetActiveDepth(kwargs: dict) -> OutgoingMessage:
-    compulsory_params = ['id', 'main_intrinsic_matrix', 'ir_intrinsic_matrix']
-    optional_params = []
-    utility.CheckKwargs(kwargs, compulsory_params)
-    msg = OutgoingMessage()
-
-    msg.write_int32(kwargs['id'])
-    msg.write_string('GetActiveDepth')
-    global main_intrinsic_matrix
-    global ir_intrinsic_matrix
-    main_intrinsic_matrix = np.reshape(kwargs['main_intrinsic_matrix'], [3, 3]).T
-    ir_intrinsic_matrix = np.reshape(kwargs['ir_intrinsic_matrix'], [3, 3]).T
-    msg.write_float32_list(ir_intrinsic_matrix.T.reshape([-1]).tolist())
-
-    return msg
-
 
 class ActiveLightSensorAttr(attr.CameraAttr):
+    """
+    红外深度传感器类，能够获取模拟真实深度相机噪声的深度图
+    """
     def __init__(self, env, id: int, data=None):
         super().__init__(env, id, data)
         self.main_intrinsic_matrix = np.eye(4)
@@ -56,14 +37,14 @@ class ActiveLightSensorAttr(attr.CameraAttr):
                                                                                         left_extrinsic_matrix,
                                                                                         right_extrinsic_matrix,
                                                                                         main_extrinsic_matrix,
-                                                                                        ir_intrinsic_matrix,
-                                                                                        ir_intrinsic_matrix,
-                                                                                        main_intrinsic_matrix,
+                                                                                        self.ir_intrinsic_matrix,
+                                                                                        self.ir_intrinsic_matrix,
+                                                                                        self.main_intrinsic_matrix,
                                                                                         lr_consistency=False,
                                                                                         main_cam_size=(
-                                                                                            main_intrinsic_matrix[
+                                                                                            self.main_intrinsic_matrix[
                                                                                                 0, 2] * 2,
-                                                                                            main_intrinsic_matrix[
+                                                                                            self.main_intrinsic_matrix[
                                                                                                 1, 2] * 2),
                                                                                         ndisp=128,
                                                                                         use_census=True,
@@ -75,14 +56,22 @@ class ActiveLightSensorAttr(attr.CameraAttr):
         return self.data
 
     def GetActiveDepth(self, main_intrinsic_matrix_local: list, ir_intrinsic_matrix_local: list):
+        """
+        获取红外深度图
+
+        Args:
+            main_intrinsic_matrix_local: List[float]主相机内参
+            ir_intrinsic_matrix_local: List[float]红外相机内参
+
+        Returns:
+            调用此接口并step后，从self.data['active_depth']获取结果
+        """
         msg = OutgoingMessage()
 
         msg.write_int32(self.id)
         msg.write_string('GetActiveDepth')
-        global main_intrinsic_matrix
-        global ir_intrinsic_matrix
-        main_intrinsic_matrix = np.reshape(main_intrinsic_matrix_local, [3, 3]).T
-        ir_intrinsic_matrix = np.reshape(ir_intrinsic_matrix_local, [3, 3]).T
-        msg.write_float32_list(ir_intrinsic_matrix.T.reshape([-1]).tolist())
+        self.main_intrinsic_matrix = np.reshape(main_intrinsic_matrix_local, [3, 3]).T
+        self.ir_intrinsic_matrix = np.reshape(ir_intrinsic_matrix_local, [3, 3]).T
+        msg.write_float32_list(self.ir_intrinsic_matrix.T.reshape([-1]).tolist())
 
         self.env.instance_channel.send_message(msg)
