@@ -142,6 +142,9 @@ def GetAmodalMask(kwargs: dict):
 
 
 class CameraAttr(attr.BaseAttr):
+    """
+    相机类，可获取各种相机截图
+    """
     def parse_message(self, msg: IncomingMessage) -> dict:
         super().parse_message(msg)
         self.data['width'] = msg.read_int32()
@@ -161,22 +164,27 @@ class CameraAttr(attr.BaseAttr):
             self.data['amodal_mask'] = base64.b64decode(msg.read_string())
         if msg.read_bool() is True:
             ddbbox_count = msg.read_int32()
-            self.data['2d_bounding_box'] = []
+            self.data['2d_bounding_box'] = {}
             for i in range(ddbbox_count):
-                self.data['2d_bounding_box'][i] = {}
-                self.data['2d_bounding_box'][i]['position'] = [msg.read_float32() for _ in range(2)]
-                self.data['2d_bounding_box'][i]['size'] = [msg.read_float32() for _ in range(2)]
+                item_id = msg.read_int32()
+                self.data['2d_bounding_box'][item_id] = {}
+                self.data['2d_bounding_box'][item_id]['position'] = [msg.read_float32() for _ in range(2)]
+                self.data['2d_bounding_box'][item_id]['size'] = [msg.read_float32() for _ in range(2)]
         if msg.read_bool() is True:
             dddbbox_count = msg.read_int32()
-            self.data['3d_bounding_box'] = []
+            self.data['3d_bounding_box'] = {}
             for i in range(dddbbox_count):
-                self.data['3d_bounding_box'][i] = {}
-                self.data['3d_bounding_box'][i]['position'] = [msg.read_float32() for _ in range(3)]
-                self.data['3d_bounding_box'][i]['rotation'] = [msg.read_float32() for _ in range(3)]
-                self.data['3d_bounding_box'][i]['size'] = [msg.read_float32() for _ in range(3)]
+                item_id = msg.read_int32()
+                self.data['3d_bounding_box'][item_id] = {}
+                self.data['3d_bounding_box'][item_id]['position'] = [msg.read_float32() for _ in range(3)]
+                self.data['3d_bounding_box'][item_id]['rotation'] = [msg.read_float32() for _ in range(3)]
+                self.data['3d_bounding_box'][item_id]['size'] = [msg.read_float32() for _ in range(3)]
         return self.data
 
     def AlignView(self):
+        """
+        使相机对准当前视口视角
+        """
         msg = OutgoingMessage()
 
         msg.write_int32(self.id)
@@ -185,6 +193,18 @@ class CameraAttr(attr.BaseAttr):
         self.env.instance_channel.send_message(msg)
 
     def GetRGB(self, width: int = 512, height: int = 512, fov: float = 60., intrinsic_matrix=None):
+        """
+        获取相机的RGB图像
+
+        Args:
+            width: 图像分辨率宽度
+            height: 图像分辨率高度
+            fov: 相机FOV
+            intrinsic_matrix: List[9]相机内参，当传入时，width、height、fov参数无效
+
+        Returns:
+            调用此接口并step后，从self.data['rgb']获取结果
+        """
         if intrinsic_matrix is None:
             intrinsic_matrix = []
 
@@ -204,6 +224,18 @@ class CameraAttr(attr.BaseAttr):
         self.env.instance_channel.send_message(msg)
 
     def GetNormal(self, width: int = 512, height: int = 512, fov: float = 60., intrinsic_matrix=None):
+        """
+        获取相机的世界空间法线图像
+
+        Args:
+            width: 图像分辨率宽度
+            height: 图像分辨率高度
+            fov: 相机FOV
+            intrinsic_matrix: List[9]相机内参，当传入时，width、height、fov参数无效
+
+        Returns:
+            调用此接口并step后，从self.data['normal']获取结果
+        """
         if intrinsic_matrix is None:
             intrinsic_matrix = []
 
@@ -223,6 +255,18 @@ class CameraAttr(attr.BaseAttr):
         self.env.instance_channel.send_message(msg)
 
     def GetID(self, width: int = 512, height: int = 512, fov: float = 60., intrinsic_matrix=None):
+        """
+        获取相机的ID图像，每个像素的颜色值由物体ID计算而来，见rfuniverse_utility.GetColorFromID
+
+        Args:
+            width: 图像分辨率宽度
+            height: 图像分辨率高度
+            fov: 相机FOV
+            intrinsic_matrix: List[9]相机内参，当传入时，width、height、fov参数无效
+
+        Returns:
+            调用此接口并step后，从self.data['id_map']获取结果
+        """
         if intrinsic_matrix is None:
             intrinsic_matrix = []
 
@@ -242,6 +286,20 @@ class CameraAttr(attr.BaseAttr):
         self.env.instance_channel.send_message(msg)
 
     def GetDepth(self, zero_dis: float, one_dis: float, width: int = 512, height: int = 512, fov: float = 60., intrinsic_matrix=None):
+        """
+        获取相机的深度图像，由于8位深度图精度低，因此需要限制范围以提高精度
+
+        Args:
+            zero_dis: 黑色像素表示深度
+            one_dis: 白像素表示深度
+            width: 图像分辨率宽度
+            height: 图像分辨率高度
+            fov: 相机FOV
+            intrinsic_matrix: List[9]相机内参，当传入时，width、height、fov参数无效
+
+        Returns:
+            调用此接口并step后，从self.data['depth']获取结果
+        """
         if intrinsic_matrix is None:
             intrinsic_matrix = []
 
@@ -263,6 +321,18 @@ class CameraAttr(attr.BaseAttr):
         self.env.instance_channel.send_message(msg)
 
     def GetDepthEXR(self, width: int = 512, height: int = 512, fov: float = 60., intrinsic_matrix=None):
+        """
+        获取相机的世界空间深度图像，EXR格式图像支持存储32位信息，因此无需限制范围
+
+        Args:
+            width: 图像分辨率宽度
+            height: 图像分辨率高度
+            fov: 相机FOV
+            intrinsic_matrix: List[9]相机内参，当传入时，width、height、fov参数无效
+
+        Returns:
+            调用此接口并step后，从self.data['depth_exr']获取结果
+        """
         if intrinsic_matrix is None:
             intrinsic_matrix = []
 
@@ -281,7 +351,20 @@ class CameraAttr(attr.BaseAttr):
 
         self.env.instance_channel.send_message(msg)
 
-    def GetAmodalMask(self, width: int = 512, height: int = 512, fov: float = 60., intrinsic_matrix=None):
+    def GetAmodalMask(self, target_id: int, width: int = 512, height: int = 512, fov: float = 60., intrinsic_matrix=None):
+        """
+        获取目标物体的Amodal Mask图像
+
+        Args:
+            target_id: 目标物体ID
+            width: 图像分辨率宽度
+            height: 图像分辨率高度
+            fov: 相机FOV
+            intrinsic_matrix: List[9]相机内参，当传入时，width、height、fov参数无效
+
+        Returns:
+            调用此接口并step后，从self.data['amodal_mask']获取结果
+        """
         if intrinsic_matrix is None:
             intrinsic_matrix = []
 
@@ -289,6 +372,7 @@ class CameraAttr(attr.BaseAttr):
 
         msg.write_int32(self.id)
         msg.write_string('GetAmodalMask')
+        msg.write_int32(target_id)
         if len(intrinsic_matrix) == 9:
             msg.write_bool(True)
             msg.write_float32_list(intrinsic_matrix)
@@ -298,4 +382,50 @@ class CameraAttr(attr.BaseAttr):
             msg.write_int32(height)
             msg.write_float32(fov)
 
-        self.env.instance_channel.send_message(msg)
\ No newline at end of file
+        self.env.instance_channel.send_message(msg)
+
+    def Get2DBBox(self, width: int = 512, height: int = 512, fov: float = 60., intrinsic_matrix=None):
+        """
+        获取相机中物体的2DBBox
+
+        Args:
+            width: 图像分辨率宽度
+            height: 图像分辨率高度
+            fov: 相机FOV
+            intrinsic_matrix: List[9]相机内参，当传入时，width、height、fov参数无效
+
+        Returns:
+            调用此接口并step后，从self.data['2d_bounding_box']获取结果
+        """
+        if intrinsic_matrix is None:
+            intrinsic_matrix = []
+
+        msg = OutgoingMessage()
+
+        msg.write_int32(self.id)
+        msg.write_string('Get2DBBox')
+        if len(intrinsic_matrix) == 9:
+            msg.write_bool(True)
+            msg.write_float32_list(intrinsic_matrix)
+        else:
+            msg.write_bool(False)
+            msg.write_int32(width)
+            msg.write_int32(height)
+            msg.write_float32(fov)
+
+        self.env.instance_channel.send_message(msg)
+
+    def Get3DBBox(self):
+        """
+        获取物体的3DBBox
+
+        Returns:
+            调用此接口并step后，从self.data['3d_bounding_box']获取结果
+        """
+        msg = OutgoingMessage()
+
+        msg.write_int32(self.id)
+        msg.write_string('Get3DBBox')
+
+        self.env.instance_channel.send_message(msg)
+
