@@ -4,7 +4,11 @@ from pyrfuniverse.side_channel.side_channel import (
     OutgoingMessage,
 )
 
+
 class ClothAttr(attr.BaseAttr):
+    """
+    ObiCloth类
+    """
     def parse_message(self, msg: IncomingMessage) -> dict:
         super().parse_message(msg)
         return self.data
\ No newline at end of file
