@@ -3,22 +3,13 @@ from pyrfuniverse.side_channel.side_channel import (
     IncomingMessage,
     OutgoingMessage,
 )
-import pyrfuniverse.utils.rfuniverse_utility as utility
 import base64
 
-def GetData(kwargs: dict) -> OutgoingMessage:
-    compulsory_params = ['id']
-    optional_params = []
-    utility.CheckKwargs(kwargs, compulsory_params)
-    msg = OutgoingMessage()
-
-    msg.write_int32(kwargs['id'])
-    msg.write_string('GetData')
-
-    return msg
-
 
 class DigitAttr(attr.BaseAttr):
+    """
+    模拟Digit指尖触觉传感器类
+    """
     def parse_message(self, msg: IncomingMessage) -> dict:
         super().parse_message(msg)
         if msg.read_bool() is True:
@@ -28,6 +19,14 @@ class DigitAttr(attr.BaseAttr):
 
 
     def GetData(self):
+        """
+        获取传感器数据
+
+        Returns:
+            调用此接口并step后，从
+            self.data['light']获取RGB灯光图像，
+            self.data['depth']获取深度图像
+        """
         msg = OutgoingMessage()
 
         msg.write_int32(self.id)
