@@ -99,6 +99,9 @@ def HumanIKTargetDoKill(kwargs: dict) -> OutgoingMessage:
 
 
 class HumanbodyAttr(attr.BaseAttr):
+    """
+    人体IK类
+    """
     def parse_message(self, msg: IncomingMessage) -> dict:
         super().parse_message(msg)
         self.data['move_done'] = msg.read_bool()
@@ -106,6 +109,19 @@ class HumanbodyAttr(attr.BaseAttr):
         return self.data
 
     def HumanIKTargetDoMove(self, index: int, position: list, duration: float, speed_based: bool = True, relative: bool = False):
+        """
+        人体IK目标点移动
+
+        Args:
+            index: 移动的目标：0-左手，1-右手，2-左脚，3-右脚，4-头部
+            position: 绝对位置或相对位置
+            duration: 移动持续时间或移动速度
+            speed_based: 指定duration表示移动持续时间还是移动速度
+            relative: 指定position表示绝对位置还是相对位置
+
+        Returns:
+            当移动完成时，self.data['move_done']会被置为True
+        """
         msg = OutgoingMessage()
 
         msg.write_int32(self.id)
@@ -121,6 +137,19 @@ class HumanbodyAttr(attr.BaseAttr):
         self.env.instance_channel.send_message(msg)
 
     def HumanIKTargetDoRotate(self, index: int, rotation: list, duration: float, speed_based: bool = True, relative: bool = False):
+        """
+        人体IK目标点旋转
+
+        Args:
+            index: 移动的目标：0-左手，1-右手，2-左脚，3-右脚，4-头部
+            rotation: 绝对旋转或相对旋转
+            duration: 旋转持续时间或旋转速度
+            speed_based: 指定duration表示旋转持续时间还是旋转速度
+            relative: 指定position表示绝对旋转还是相对旋转
+
+        Returns:
+            当旋转完成时，self.data['rotate_done']会被置为True
+        """
         msg = OutgoingMessage()
 
         msg.write_int32(self.id)
@@ -136,8 +165,19 @@ class HumanbodyAttr(attr.BaseAttr):
         self.env.instance_channel.send_message(msg)
 
     def HumanIKTargetDoRotateQuaternion(self, index: int, quaternion: list, duration: float, speed_based: bool = True, relative: bool = False):
-        msg = OutgoingMessage()
+        """
+        人体IK目标点四元数旋转
 
+        Args:
+            index: 移动的目标：0-左手，1-右手，2-左脚，3-右脚，4-头部
+            quaternion: 绝对旋转或相对旋转
+            duration: 旋转持续时间或旋转速度
+            speed_based: 指定duration表示旋转持续时间还是旋转速度
+            relative: 指定position表示绝对旋转还是相对旋转
+
+        Returns:
+            当旋转完成时，self.data['rotate_done']会被置为True
+        """
         msg = OutgoingMessage()
 
         msg.write_int32(self.id)
@@ -156,6 +196,12 @@ class HumanbodyAttr(attr.BaseAttr):
         self.env.instance_channel.send_message(msg)
 
     def HumanIKTargetDoComplete(self, index: int):
+        """
+        使人体IK目标点移动/旋转立即完成
+
+        Args:
+            index: 移动的目标：0-左手，1-右手，2-左脚，3-右脚，4-头部
+        """
         msg = OutgoingMessage()
 
         msg.write_int32(self.id)
@@ -165,6 +211,12 @@ class HumanbodyAttr(attr.BaseAttr):
         self.env.instance_channel.send_message(msg)
 
     def HumanIKTargetDoKill(self, index: int):
+        """
+        使人体IK目标点移动/旋转停止
+
+        Args:
+            index: 移动的目标：0-左手，1-右手，2-左脚，3-右脚，4-头部
+        """
         msg = OutgoingMessage()
 
         msg.write_int32(self.id)
@@ -174,6 +226,9 @@ class HumanbodyAttr(attr.BaseAttr):
         self.env.instance_channel.send_message(msg)
 
     def WaitDo(self):
+        """
+        等待人体IK移动/旋转完成
+        """
         while not self.data['move_done'] or not self.data['rotate_done']:
             self.env.step()
 
