@@ -5,12 +5,26 @@ from pyrfuniverse.side_channel.side_channel import (
     IncomingMessage,
     OutgoingMessage,
 )
+
+
 class PointCloudAttr(attr.BaseAttr):
+    """
+    点云渲染类
+    """
     def parse_message(self, msg: IncomingMessage) -> dict:
         super().parse_message(msg)
         return self.data
 
     def ShowPointCloud(self, positions: list = [], colors: list = [], ply_path: str = None, radius: float = 0.01):
+        """
+        显示点云
+
+        Args:
+            positions: 点位置列表
+            colors: 点颜色列表
+            ply_path: .ply文件列表，如果不为空，则positions和colors参数无效
+            radius: 点半径
+        """
         msg = OutgoingMessage()
 
         msg.write_int32(self.id)
@@ -26,6 +40,12 @@ class PointCloudAttr(attr.BaseAttr):
         self.env.instance_channel.send_message(msg)
 
     def SetRadius(self, radius: float):
+        """
+        设置点半径
+
+        Args:
+            radius: 半径
+        """
         msg = OutgoingMessage()
 
         msg.write_int32(self.id)
