@@ -5,6 +5,9 @@ from pyrfuniverse.side_channel.side_channel import (
 )
 
 class SoftbodyAttr(attr.BaseAttr):
+    """
+    ObiSoftbody类
+    """
     def parse_message(self, msg: IncomingMessage) -> dict:
         super().parse_message(msg)
         return self.data
\ No newline at end of file
