@@ -3,7 +3,7 @@ import pyrfuniverse.attributes as attr
 import cv2
 import numpy as np
 
-env = RFUniverseBaseEnv()
+env = RFUniverseBaseEnv(assets=['Camera'])
 
 camera = env.InstanceObject(name='Camera', id=123456, attr_type=attr.CameraAttr)
 camera.SetTransform(position=[0, 0.25, 0], rotation=[30, 0, 0])
@@ -11,9 +11,9 @@ camera.GetDepth(width=512, height=512, zero_dis=1, one_dis=5)
 camera.GetDepthEXR(width=512, height=512)
 camera.GetRGB(width=512, height=512)
 env.step()
-print(camera.data['rgb'])
 print(camera.data['depth'])
 print(camera.data['depth_exr'])
+print(camera.data['rgb'])
 image_np = np.frombuffer(camera.data['rgb'], dtype=np.uint8)
 image_np = cv2.imdecode(image_np, cv2.IMREAD_COLOR)
 print(image_np.shape)
