@@ -4,11 +4,11 @@ import os
 
 env = RFUniverseBaseEnv()
 
-ur5 = env.LoadURDF(id=639787, path=os.path.abspath('../URDF/UR5/ur5_robot.urdf'), native_ik=True)
+ur5 = env.LoadURDF(path=os.path.abspath('../URDF/UR5/ur5_robot.urdf'), native_ik=True)
 ur5.SetTransform(position=[1, 0, 0])
-yumi = env.LoadURDF(id=358136, path=os.path.abspath('../URDF/yumi_description/urdf/yumi.urdf'), native_ik=False)
+yumi = env.LoadURDF(path=os.path.abspath('../URDF/yumi_description/urdf/yumi.urdf'), native_ik=False)
 yumi.SetTransform(position=[2, 0, 0])
-kinova = env.LoadURDF(id=985135, path=os.path.abspath('../URDF/kinova_gen3/GEN3_URDF_V12.urdf'), native_ik=False)
+kinova = env.LoadURDF(path=os.path.abspath('../URDF/kinova_gen3/GEN3_URDF_V12.urdf'), native_ik=False)
 kinova.SetTransform(position=[3, 0, 0])
 
 ur5.IKTargetDoMove(position=[0, 0.5, 0], duration=0.1, relative=True)
